@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Play the tabla!
 
-our $VERSION = '0.0401';
+our $VERSION = '0.0402';
 
 use Moo;
 use File::ShareDir qw(dist_dir);
@@ -51,19 +51,13 @@ sub BUILD {
 
 sub strike {
     my ($self, $bol, $dura, $index) = @_;
+    $dura ||= $self->quarter;
     my $patches = $self->patches->{$bol};
-    my $patch = _patch_index($patches, $index);
-    $patch ||= 60;
-    $dura  ||= $self->quarter;
+    $index = int rand @$patches if $patches && (!defined $index || $index < 0);
+    my $patch = $patches->[$index] || 60;
     $self->note($dura, $patch);
 }
 
-sub _patch_index {
-    my ($patches, $index) = @_;
-    $index = int rand @$patches if !defined $index || $index < 0;
-    return $patches->[$index];
-}
-
 1;
 
 __END__
@@ -78,7 +72,7 @@ Music::Percussion::Tabla - Play the tabla!
 
 =head1 VERSION
 
-version 0.0401
+version 0.0402
 
 =head1 SYNOPSIS
 
